@@ -1,24 +1,34 @@
+# Slices an array or hash into pieces of a given size.
+#
 # This function takes two mandatory arguments: the first should be an array or hash, and the second specifies
 # the number of elements to include in each slice.
 #
 # When the first argument is a hash, each key value pair is counted as one. For example, a slice size of 2 will produce
 # an array of two arrays with key, and value.
 #
-#     $a.slice(2) |$entry|          { notice "first ${$entry[0]}, second ${$entry[1]}" }
-#     $a.slice(2) |$first, $second| { notice "first ${first}, second ${second}" }
+# @example Slicing a Hash
 #
+# ```puppet
+# $a.slice(2) |$entry|          { notice "first ${$entry[0]}, second ${$entry[1]}" }
+# $a.slice(2) |$first, $second| { notice "first ${first}, second ${second}" }
+# ```
 # The function produces a concatenated result of the slices.
 #
-#     slice([1,2,3,4,5,6], 2) # produces [[1,2], [3,4], [5,6]]
-#     slice(Integer[1,6], 2)  # produces [[1,2], [3,4], [5,6]]
-#     slice(4,2)              # produces [[0,1], [2,3]]
-#     slice('hello',2)        # produces [[h, e], [l, l], [o]]
+# @example Slicing an Array
 #
+# ```puppet
+# slice([1,2,3,4,5,6], 2) # produces [[1,2], [3,4], [5,6]]
+# slice(Integer[1,6], 2)  # produces [[1,2], [3,4], [5,6]]
+# slice(4,2)              # produces [[0,1], [2,3]]
+# slice('hello',2)        # produces [[h, e], [l, l], [o]]
+# ```
 #
-# You can also optionally pass a lambda to slice.
+# @example Passing a lambda to a slice (optional)
 #
-#     $a.slice($n) |$x| { ... }
-#     slice($a) |$x| { ... }
+# ```puppet
+#  $a.slice($n) |$x| { ... }
+#  slice($a) |$x| { ... }
+# ```
 #
 # The lambda should have either one parameter (receiving an array with the slice), or the same number
 # of parameters as specified by the slice size (each parameter receiving its part of the slice).
@@ -26,7 +36,11 @@
 # elements. If the lambda has multiple parameters, excess parameters are set to undef for an array, or
 # to empty arrays for a hash.
 #
+# @example Getting individual values of a slice
+#
+# ```puppet
 #     $a.slice(2) |$first, $second| { ... }
+# ```
 #
 # @since 4.0.0
 #
@@ -102,9 +116,8 @@ Puppet::Functions.create_function(:slice) do
       raise ArgumentError, _("slice(): block must define at least one parameter. Block has 0.")
     end
     unless serving_size == 1 || serving_size == slice_size
-      raise ArgumentError, _("slice(): block must define one parameter, or ") +
-        _("the same number of parameters as the given size of the slice (%{slice_size}). Block has %{serving_size}; ") % { slice_size: slice_size, serving_size: serving_size }+
-      pblock.parameter_names.join(', ')
+      raise ArgumentError, _("slice(): block must define one parameter, or the same number of parameters as the given size of the slice (%{slice_size}). Block has %{serving_size}; %{parameter_names}") %
+          { slice_size: slice_size, serving_size: serving_size, parameter_names: pblock.parameter_names.join(', ') }
     end
     serving_size
   end
